/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.asynch;


/**
 * Interface used to report the status of an 'asynchrone task' in a simple dialog. <br>
 * An 'asynchrone task' is simply any task executed in a thread that is not the Swing event dispatch thread.
 * 
 * @author Olivier Berlanger
 */
public interface AsynchStatusProvider {


    public enum ActionStatus {
        RUNNING, DONE, ABORTED, FAILED, TO_DISPOSE
    }


    /**
     * Return unique id for build GUI keys (for translations and settings).
     */
    public String getProviderId();


    public int getStatusLineCount();


    public String getStatusLine(int index);


    public boolean hasStatusLineChanged(int index);


    public boolean displayCancelButton();


    public boolean isCancelAllowed();


    public void cancelAction();


    public boolean displayOkButton();


    public void okAction();


    public boolean displayProgressBar();


    public ActionStatus getStatus();


    public int getPercentComplete();

}
