/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor;


import net.sf.sfac.editor.EditorConfig;


/**
 * Object used to turn an EditorConfig annotation to properties that are set on a ObjectEditor.
 * 
 * @author Olivier Berlanger
 */
public class EditorConfigHelper {


    public static void setProperties(ObjectEditor editor, EditorConfig config, String defaultName) {
        if (config != null) {
            setStringProperty(ObjectEditor.EDITOR_LABEL_PROPERTY, config.label(), defaultName, editor);
            setStringProperty(ObjectEditor.EDITOR_DESCRIPTION_PROPERTY, config.description(), null, editor);
            setStringProperty(ObjectEditor.EDITOR_TYPE_PROPERTY, config.type(), null, editor);
            setStringProperty(ObjectEditor.TAB_PROPERTY, config.tab(), null, editor);
            setStringProperty(ObjectEditor.EDITOR_LIST_PROPERTY, config.list(), null, editor);
            setStringProperty(ObjectEditor.VISIBILITY_PROPERTY, config.visibility(), null, editor);
            setStringProperty(ObjectEditor.EDITABLE_PROPERTY, config.editable(), null, editor);
            setStringProperty(ObjectEditor.ENABLED_PROPERTY, config.enabled(), null, editor);

            int index = config.index();
            if (index != -1) {
                editor.setProperty(ObjectEditor.EDITOR_INDEX_PROPERTY, Integer.valueOf(index));
            }

            String[] properties = config.properties();
            int len = properties.length;
            for (int i = 0; i < len; i += 2) {
                editor.setProperty(properties[i], getConvertedPropertyValue(properties[i], properties[i + 1]));
            }
        }
    }


    private static void setStringProperty(String propertyKey, String propertyValue, String defaultValue, ObjectEditor editor) {
        if (propertyValue.equals(EditorConfig.UNDEFINED)) {
            if (defaultValue != null) editor.setProperty(propertyKey, defaultValue);
        } else {
            editor.setProperty(propertyKey, propertyValue);
        }
    }


    private static Object getConvertedPropertyValue(String key, String value) {
        if ("fill".equals(key)) return new Integer(value);
        if ("weightx".equals(key)) return new Double(value);
        if ("weighty".equals(key)) return new Double(value);
        return value;
    }


}
