/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor;


import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import net.sf.sfac.setting.Settings;


/**
 * Base implementation of the EditorContex interface.
 * 
 * @author Olivier Berlanger
 */
public class EditorContextImpl implements EditorContext {

    private EditorFactory factory;
    private Settings sett;
    private Map<String, Object> contextObjects;
    private ObjectEditor rootEditor;


    public EditorContextImpl(Settings newSett) {
        sett = newSett;
    }


    public EditorContextImpl(Settings newSett, ObjectEditor newRootEditor) {
        sett = newSett;
        rootEditor = newRootEditor;
    }


    public EditorContextImpl(Settings newSett, EditorFactory newFactory, ObjectEditor newRootEditor) {
        factory = newFactory;
        sett = newSett;
        setRootEditor(newRootEditor);
    }


    public void setRootEditor(ObjectEditor newRootEditor) {
        if (rootEditor != null) rootEditor.setEditorContext(null);
        rootEditor = newRootEditor;
        if (rootEditor != null) rootEditor.setEditorContext(this);
    }


    public ObjectEditor getRootEditor() {
        return rootEditor;
    }


    public Collection<ObjectEditor> getEditors() {
        if (rootEditor == null) return Collections.emptyList();
        return Collections.singleton(rootEditor);
    }


    public boolean canEditInContext(boolean create, Class<?> objectClass, ObjectEditor source) {
        return false;
    }


    public <T> T editInContext(T obj, Class<T> objectClass, ObjectEditor source) {
        throw new UnsupportedOperationException("editInContext is not supported in EditorContextImpl");
    }


    public EditorFactory getEditorFactory() {
        return (factory == null) ? EditorFactory.getInstance() : factory;
    }


    public Settings getSettings() {
        return sett;
    }


    public void setSettings(Settings newSett) {
        sett = newSett;
    }


    public void setFactory(EditorFactory newFactory) {
        factory = newFactory;
    }


    public Object getContextObject(String objectKey) {
        if (contextObjects == null) return null;
        return contextObjects.get(objectKey);
    }


    public void putContextObjects(String key, Object value) {
        if (contextObjects == null) contextObjects = new HashMap<String, Object>();
        contextObjects.put(key, value);
    }

}
