/*-------------------------------------------------------------------------
 Copyright 2012 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor;


import java.util.ArrayList;
import java.util.List;

import net.sf.sfac.utils.Comparison;


/**
 * Event raised by an ObjectEditor to notify any state change.
 */
public class EditorModificationEvent {

    public enum EditorModificationType {
        EDITED_VALUE, COMPONENT_LAYOUT, COMPONENT_VISIBILITY, COMPONENT_EDITABLE
    }

    private EditorModificationType modificationType;
    private ObjectEditor source;
    private Object oldValue;
    private EditorModificationEvent sub;


    public EditorModificationEvent(ObjectEditor leafSourceEditor, Object oldEditedValue) {
        modificationType = EditorModificationType.EDITED_VALUE;
        source = leafSourceEditor;
        oldValue = oldEditedValue;
    }


    public EditorModificationEvent(EditorModificationType modifType, ObjectEditor leafSourceEditor, Object oldEditedValue) {
        modificationType = modifType;
        source = leafSourceEditor;
        oldValue = oldEditedValue;
    }


    public EditorModificationEvent(ObjectEditor sourceEditor, EditorModificationEvent subEvent) {
        modificationType = subEvent.getModificationType();
        source = sourceEditor;
        sub = subEvent;
    }


    public EditorModificationType getModificationType() {
        return modificationType;
    }


    public ObjectEditor getSourceEditor() {
        return source;
    }


    public ObjectEditor getLeafEditor() {
        return (sub == null) ? source : sub.getLeafEditor();
    }


    public Object getNewValue() {
        return (sub == null) ? source.getModelAccess().getModelValue(source.getEditedObject()) : sub.getNewValue();
    }


    public Object getOldValue() {
        return (sub == null) ? oldValue : sub.getOldValue();
    }


    public List<ObjectEditor> getEditorPath() {
        List<ObjectEditor> subList = (sub == null) ? new ArrayList<ObjectEditor>() : sub.getEditorPath();
        subList.add(0, source);
        return subList;
    }


    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(getClass().getSimpleName());
        sb.append("[");
        sb.append(modificationType);
        sb.append(", path='");
        sb.append(getValuePath());
        sb.append("', oldValue=");
        sb.append(getLeafEvent().oldValue);
        sb.append("]");
        return sb.toString();
    }


    private EditorModificationEvent getLeafEvent() {
        if (sub == null) return this;
        return sub.getLeafEvent();
    }


    public String getValuePath() {
        StringBuilder sb = new StringBuilder();
        EditorModificationEvent ev = this;
        while (ev != null) {
            String path = ev.source.getModelAccess().getFieldPath();
            if (Comparison.isDefined(path)) {
                if (sb.length() > 0) sb.append(".");
                sb.append(path);
            }
            ev = ev.sub;
        }
        return sb.toString();
    }

}
