/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor;


/**
 * Interface used by an Object editor to access its model value inside the edited object. <br>
 * Note: the model value can be the edited object itself or an attribute of it.
 * 
 * @author Olivier Berlanger
 */
public interface ModelAccess {

    /**
     * Get the actual value to be edited out of the editedObject.
     */
    public Object getModelValue(Object editedObject);


    /**
     * Set the edited value in the editedObject.
     */
    public void setModelValue(Object newModelValue, Object editedObject);


    /**
     * return the class of the edited object (the one passed as parameter to the getModelValue(...) method).
     */
    public Class<?> getEditedObjectClass();


    /**
     * return the class of the ModelValue object (the one returned by the getModelValue(...) method).
     */
    public Class<?> getModelClass();


    /**
     * Return true if this ModelAccess is able to support model update. <br>
     * Returning false will force any editor based on this modelAccess to be read-only.
     */
    public boolean canUpdateModel();


    /**
     * Get path to the edited field starting from the base object given to the editor. <br>
     * The returned value is a beanUtils-like path. If the returned path is null (or "") it means that the editor directly edit the
     * given object (= getModelValue(...) directly return the object passed as parameter and setModelValue(...) does nothing).
     */
    public String getFieldPath();

}
