/*-------------------------------------------------------------------------
 Copyright 2012 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.access;


import net.sf.sfac.gui.editor.ModelAccess;


/**
 * Implementation of the ModelAccess interface the same fixed value (given in constructor) is always returned.
 * 
 * @author Olivier Berlanger
 */
public class FixedModelAccess implements ModelAccess {

    private Object value;


    public FixedModelAccess(Object fixedValue) {
        value = fixedValue;
    }


    public Object getModelValue(Object baseObject) {
        return value;
    }


    public void setModelValue(Object newModelValue, Object baseObject) {
        throw new UnsupportedOperationException("Setter not available in: " + getClass());
    }


    public boolean canUpdateModel() {
        return false;
    }


    public Class<?> getModelClass() {
        return value.getClass();
    }


    public Class<?> getEditedObjectClass() {
        return null;
    }


    public String getFieldPath() {
        return "_value_";
    }


    @Override
    public String toString() {
        return getClass().getSimpleName() + "[" + value + "]";
    }

}
