/*-------------------------------------------------------------------------
 Copyright 2012 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.access;


import net.sf.sfac.gui.editor.ModelAccess;
import net.sf.sfac.lang.LanguageSupport;


/**
 * Implementation of the ModelAccess adding translation to the chained model access. <br>
 * Translation is done with the LanguageSupport and supposes that the chained model access returns strings.
 * 
 * @author Olivier Berlanger
 */
public class TranslationModelAccess extends ChainableModelAccess {


    public TranslationModelAccess(ModelAccess chained) {
        if (chained == null) throw new IllegalArgumentException("Chained model cannot be null");
        setParent(chained);
    }


    @Override
    public Object getModelValue(Object baseObject) {
        Object editedObject = super.getModelValue(baseObject);
        if (editedObject == null) return null;
        String key = editedObject.toString();
        return LanguageSupport.getLocalizedString(key);
    }


    public void setModelValue(Object newModelValue, Object baseObject) {
        throw new UnsupportedOperationException("TranslationModelAccess does not support setModelValue");
    }


    public boolean canUpdateModel() {
        return false;
    }


    public Class<?> getModelClass() {
        return String.class;
    }


    @Override
    public String getThisFieldPath() {
        return "translate:";
    }


    @Override
    public Class<?> getThisEditedObjectClass() {
        return null;
    }


}
