/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.cmp;


import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.sf.sfac.utils.Comparison;


/**
 * Editor used to edit a Dimension value.
 * 
 * @author Olivier Berlanger
 */
public class DimensionEditor extends SimpleObjectEditor {


    private JPanel component;
    private JTextField widthField;
    private JTextField heightField;


    public JComponent getObjectComponent() {
        if (component == null) {
            widthField = new JTextField(6);
            registerFocusListener(widthField);
            heightField = new JTextField(6);
            registerFocusListener(heightField);
            // Put them in a JPanel
            component = new JPanel(new GridBagLayout());
            component.add(widthField, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER,
                    GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 5), 0, 0));
            component.add(new JLabel("x"), new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER,
                    GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 5), 0, 0));
            component.add(heightField, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER,
                    GridBagConstraints.HORIZONTAL, new Insets(0, 5, 0, 0), 0, 0));
            component.add(new JLabel(), new GridBagConstraints(3, 0, 1, 1, 1.0, 0.0, GridBagConstraints.CENTER,
                    GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 5), 0, 0));
            synchronizeEditableState();
            updateView();
        }
        return component;
    }


    @Override
    protected void synchronizeEditableState() {
        if (widthField != null) {
            widthField.setEditable(isEditable());
            widthField.setEnabled(isEnabled());
            heightField.setEditable(isEditable());
            heightField.setEnabled(isEnabled());
        }
    }


    @Override
    protected boolean isViewReady() {
        return (widthField != null);
    }


    @Override
    protected Object getViewValue() {
        int width = getIntValue(widthField);
        int height = getIntValue(heightField);
        if ((width < 0) || (height < 0)) return null;
        return new Dimension(width, height);
    }


    private int getIntValue(JTextField field) {
        int result = -1;
        String text = field.getText();
        if (Comparison.isDefined(text)) {
            try {
                result = Integer.parseInt(text);
            } catch (Exception e) {
                field.setText("");
            }
        }
        return result;
    }


    @Override
    protected void setViewValue(Object modelValue) {
        Dimension dim = (Dimension) modelValue;
        if (dim == null) {
            widthField.setText("");
            heightField.setText("");
        } else {
            widthField.setText(String.valueOf(dim.width));
            heightField.setText(String.valueOf(dim.height));
        }
    }


}
