/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.editor.cmp;


import javax.swing.JComponent;
import javax.swing.JLabel;


/**
 * Editor that is in fact just a label. <br>
 * This editor is a 'hack' to easily add labels in your generated form (possibly trough annotations). This editor works like a
 * StringEditor but with a JLabel instead of the JTextField. So, as a direct result, it is read-only. It's useful to add text,
 * subtitles, sections, comments (remember that JLabel is able to render HTML), ... <br>
 * Note that, in most of the case you don't want that this label has another label before it, so you have to define label="" in
 * EditorConfig annotation.
 * 
 * @author Olivier Berlanger
 */
public class LabelEditor extends SimpleObjectEditor {


    private JLabel component;


    public JComponent getObjectComponent() {
        if (component == null) {
            component = new JLabel();
        }
        return component;
    }


    @Override
    protected boolean isViewReady() {
        return component != null;
    }


    @Override
    protected boolean valueHasChanged(Object oldValue, Object newValue) {
        // always return false as this editor is read-only
        return false;
    }


    @Override
    protected Object getViewValue() {
        // never used as updateModel() is overridden
        return null;
    }


    @Override
    protected void setViewValue(Object newModelValue) {
        if (component != null) {
            String text = (newModelValue == null) ? "" : newModelValue.toString();
            component.setText(text);
        }
    }


    @Override
    public void updateModel() {
        // Does nothing as this editor is read-only
    }


    @Override
    protected void synchronizeEditableState() {
    }


}
