/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.layout;


import java.awt.Container;
import java.awt.Dimension;
import java.awt.Insets;

import javax.swing.JCheckBox;
import javax.swing.UIManager;
import javax.swing.border.Border;


/**
 * CheckBoxBorder is a ActionBorder with a check box enabling to expand/collapse or enable/disable its content.
 * 
 * @author Olivier Berlanger
 * @see ActionBorder
 * @see MultiBorderLayout
 * @see MultiBorderConstraints
 */
public class CheckBoxBorder extends ActionBorder {


    private JCheckBox checkBox;


    /**
     * Creates an ExpandBorder using an TitledBorder with the given title.
     * 
     * @param title
     *            the title of the titled border.
     * @param borderAction
     *            the action the border has to execute when the checkBox is selected. One of ActionBorder.ACTION_COLLAPSE or
     *            ActionBorder.ACTION_DISABLE.
     */
    public CheckBoxBorder(String title, int borderAction) {
        super(UIManager.getBorder("TitledBorder.border"));
        init(title, borderAction);
    }


    /**
     * Creates an ExpandBorder using the given border.
     * 
     * @param thePaintedBorder
     *            the border painted by this MultiBorder
     * @param title
     *            the title of the titled border.
     * @param borderAction
     *            the action the border has to execute when the checkBox is selected. One of ActionBorder.ACTION_COLLAPSE or
     *            ActionBorder.ACTION_DISABLE.
     */
    public CheckBoxBorder(Border thePaintedBorder, String title, int borderAction) {
        super(thePaintedBorder);
        init(title, borderAction);
    }


    private void init(String title, int action) {
        setBorderAction(action);
        checkBox = new JCheckBox(title);
        checkBox.setSelected(true);
        setControlButton(checkBox);
    }


    public String toString() {
        return getClass().getName() + "['" + checkBox.getText() + "']";
    }


    protected void updateInsets(Insets insetToUpdate) {
        insetToUpdate.top += 4;
        insetToUpdate.left += 4;
        insetToUpdate.bottom += 4;
        insetToUpdate.right += 4;
        super.updateInsets(insetToUpdate);
    }


    // //////////// Overriden methods of ActionBorder ////////////////////////////////////////////


    protected void layoutExtraComponents(Container cont) {
        Dimension dim = checkBox.getPreferredSize();
        int posX = x + CONTROL_BUTTON_SPACE;
        int posY = y + ((getUpdatedInsets(cont).top - dim.height) / 2);
        checkBox.setBounds(posX, posY, dim.width, dim.height);
    }


}
