/*-------------------------------------------------------------------------
 Copyright 2012 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.profiles;


import java.util.ArrayList;
import java.util.List;

import net.sf.sfac.gui.editor.cmp.ComboBoxEditor;
import net.sf.sfac.gui.profiles.ProfilesController.StoreProfileParams;
import net.sf.sfac.gui.utils.VariableComboBoxModel;
import net.sf.sfac.setting.SubSettingsList;
import net.sf.sfac.setting.SubSettingsProxy;


/**
 * Editor display the list of all available profiles (when saving a profile with the 'override' option).
 * 
 * @author Olivier Berlanger
 */
public class ProfilesComboEditor extends ComboBoxEditor {


    private VariableComboBoxModel model;


    public ProfilesComboEditor() {
        super(new VariableComboBoxModel(new Object[] { null }));
        model = (VariableComboBoxModel) getComboBoxModel();
    }


    @Override
    public void edit(Object objToEdit) {
        setupAvailableValues((StoreProfileParams) objToEdit);
        super.edit(objToEdit);
    }


    private void setupAvailableValues(StoreProfileParams params) {
        List<String> profileNames = new ArrayList<String>();
        SubSettingsList subs = params.getProfileList();
        int nbrProfiles = subs.getSize();
        for (int i = 0; i < nbrProfiles; i++) {
            SubSettingsProxy proxy = (SubSettingsProxy) subs.getSubSettingAt(i);
            profileNames.add(proxy.getName());
        }
        model.setAvailableValues(profileNames.toArray());
    }


}
