/*-------------------------------------------------------------------------
 Copyright 2009 Olivier Berlanger

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 -------------------------------------------------------------------------*/
package net.sf.sfac.gui.utils;


import java.awt.Component;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.MouseEvent;
import java.util.ArrayList;
import java.util.EventObject;
import java.util.List;

import javax.swing.ComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.JTable;
import javax.swing.event.CellEditorListener;
import javax.swing.event.ChangeEvent;
import javax.swing.table.TableCellEditor;


/**
 * Table cell editor for enumerated values.
 * 
 * @author Olivier Berlanger
 */
@SuppressWarnings("serial")
public class ComboCellEditor extends JComboBox implements TableCellEditor {

    private List<CellEditorListener> editorListenerList = new ArrayList<CellEditorListener>();


    public ComboCellEditor(ComboBoxModel model) {
        super(model);
        setKeySelectionManager(new ComboBoxKeyManager());
        registerListeners();
    }


    public ComboCellEditor(Class<? extends Enum<?>> displayedClass) {
        super(new VariableComboBoxModel(displayedClass.getEnumConstants()));
        registerListeners();
    }


    private void registerListeners() {
        addFocusListener(new FocusListener() {

            public void focusLost(FocusEvent newE) {
                stopCellEditing();
            }


            public void focusGained(FocusEvent newE) {
            }

        });
    }


    // ----------------------- CellEditor Interface implementation ----------------------------------------------

    public Object getCellEditorValue() {
        return getSelectedItem();
    }


    public boolean isCellEditable(EventObject anEvent) {
        if (anEvent instanceof MouseEvent) {
            return ((MouseEvent) anEvent).getClickCount() >= 2;
        }
        return true;
    }


    public boolean shouldSelectCell(EventObject anEvent) {
        return true;
    }


    public boolean stopCellEditing() {
        fireEditingStopped();
        return true;
    }


    public void cancelCellEditing() {
        fireEditingCanceled();
    }


    public void addCellEditorListener(CellEditorListener l) {
        editorListenerList.add(l);
    }


    public void removeCellEditorListener(CellEditorListener l) {
        editorListenerList.remove(l);
    }


    /**
     * Notify all listeners that have registered interest for notification on this event type.
     */
    protected void fireEditingStopped() {
        int len = editorListenerList.size();
        ChangeEvent changeEvent = new ChangeEvent(this);
        for (int i = 0; i < len; i++) {
            editorListenerList.get(i).editingStopped(changeEvent);
        }
    }


    /**
     * Notify all listeners that have registered interest for notification on this event type.
     */
    protected void fireEditingCanceled() {
        int len = editorListenerList.size();
        ChangeEvent changeEvent = new ChangeEvent(this);
        for (int i = 0; i < len; i++) {
            editorListenerList.get(i).editingCanceled(changeEvent);
        }
    }


    public Component getTableCellEditorComponent(JTable table, Object value, boolean isSelected, int row, int column) {
        editorListenerList.clear();
        getModel().setSelectedItem(value);
        return this;
    }

}
